
#ifndef _C14_se686_
#define _C14_se686_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F772_6267(EIF_REFERENCE);
extern void F772_6269(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit686(void);
extern char *(*R5447[])();
extern char *(*R5426[])();

#ifdef __cplusplus
}
#endif

#endif
